@@ -21,7 +21,7 @@ setMethod("polygons", signature(obj = "SpatialPolygons"),
 names.SpatialPolygonsDataFrame = function(x) names(x@data)
 "names<-.SpatialPolygonsDataFrame" = function(x,value) { names(x@data) = value; x }
 
-as.data.frame.SpatialPolygonsDataFrame = function(x, row.names, optional) x@data
+as.data.frame.SpatialPolygonsDataFrame = function(x, row.names, optional, ...) x@data
 
 setAs("SpatialPolygonsDataFrame", "data.frame", function(from)
     as.data.frame.SpatialPolygonsDataFrame(from))
